==> auto-ui-0.1.7.tgz: package/es/navbar/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import './style.scss';
import React from 'react';
import cn from 'classnames';
import Toast from '../toast';

var NavBar =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(NavBar, _React$Component);

  function NavBar() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "leftClick", function () {
      window.history.go(-1);
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "rightClick", function () {
      Toast('点击了功能按钮');
    });

    return _this;
  }

  var _proto = NavBar.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        title = _this$props.title,
        className = _this$props.className,
        leftBtn = _this$props.leftBtn,
        rightBtn = _this$props.rightBtn,
        leftClick = _this$props.leftClick,
        rightClick = _this$props.rightClick,
        otherProps = _objectWithoutPropertiesLoose(_this$props, ["title", "className", "leftBtn", "rightBtn", "leftClick", "rightClick"]);

    var composeClass = cn('auto-ui_navbar', className);
    return React.createElement("div", _extends({}, otherProps, {
      className: composeClass
    }), leftBtn && React.createElement("div", {
      className: "auto-ui_navbar-leftbtn",
      onClick: leftClick || this.leftClick
    }, React.createElement("i", {
      className: "auto-ui_navbar-icon auto-ui_navbar-leftbtn-icon"
    })), React.createElement("div", {
      className: "auto-ui_navbar-title"
    }, title), rightBtn && React.createElement("div", {
      className: "auto-ui_navbar-rightbtn",
      onClick: rightClick || this.rightClick
    }, React.createElement("i", {
      className: "auto-ui_navbar-icon auto-ui_navbar-rightbtn-icon"
    })));
  };

  return NavBar;
}(React.Component);

export default NavBar;

==> auto-ui-0.1.9.tgz: package/es/navbar/index.js <==
import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _assertThisInitialized from "@babel/runtime/helpers/esm/assertThisInitialized";
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import './style.scss';
import React from 'react';
import cn from 'classnames';

var NavBar =
/*#__PURE__*/
function (_React$Component) {
  _inheritsLoose(NavBar, _React$Component);

  function NavBar() {
    var _this;

    for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    _this = _React$Component.call.apply(_React$Component, [this].concat(args)) || this;

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "leftClick", function (e) {
      window.history.go(-1);
    });

    _defineProperty(_assertThisInitialized(_assertThisInitialized(_this)), "rightClick", function (e) {
      window.location.href = window.location.origin + '/m/index';
    });

    return _this;
  }

  var _proto = NavBar.prototype;

  _proto.render = function render() {
    var _this$props = this.props,
        title = _this$props.title,
        className = _this$props.className,
        leftBtn = _this$props.leftBtn,
        rightBtn = _this$props.rightBtn,
        leftClick = _this$props.leftClick,
        rightClick = _this$props.rightClick,
        dark = _this$props.dark,
        otherProps = _objectWithoutPropertiesLoose(_this$props, ["title", "className", "leftBtn", "rightBtn", "leftClick", "rightClick", "dark"]);

    var composeClass = cn('auto-ui_navbar', {
      'auto-ui_navbar-dark': dark
    }, className);
    return React.createElement("div", _extends({}, otherProps, {
      className: composeClass
    }), leftBtn && React.createElement("div", {
      className: "auto-ui_navbar-leftbtn",
      onClick: leftClick || this.leftClick
    }, leftBtn === true ? React.createElement("i", {
      className: "auto-ui_navbar-icon auto-ui_navbar-leftbtn-icon"
    }) : leftBtn), React.createElement("div", {
      className: "auto-ui_navbar-title"
    }, title), rightBtn && React.createElement("div", {
      className: "auto-ui_navbar-rightbtn",
      onClick: function onClick(e) {
        rightClick && rightClick(e);
      }
    }, rightBtn === true ? React.createElement("i", {
      className: "auto-ui_navbar-icon auto-ui_navbar-rightbtn-icon"
    }) : rightBtn));
  };

  return NavBar;
}(React.Component);

export default NavBar;
